@@ -130,7 +130,13 @@ export class CdkTestStack extends Stack {
     // Enable adding suppressions to child constructs
     NagSuppressions.addResourceSuppressions(
       user,
-      [{ id: 'AwsSolutions-IAM5', reason: 'lorem ipsum' }],
+      [
+        {
+          id: 'AwsSolutions-IAM5',
+          reason: 'lorem ipsum',
+          appliesTo: ['Resource::arn:aws:s3:::bucket_name/*'], // optional
+        },
+      ],
       true
     );
   }
@@ -184,6 +190,74 @@ export class CdkTestStack extends Stack {
 }
 ```
 
+</details><details>
+  <summary>Example 5) Granular Suppressions of findings</summary>
+
+Certain rules support granular suppressions of `findings`. If you received the following errors on synth/deploy
+
+```bash
+[Error at /StackName/rFirstUser/DefaultPolicy/Resource] AwsSolutions-IAM5[Action::s3:*]: The IAM entity contains wildcard permissions and does not have a cdk_nag rule suppression with evidence for those permission.
+[Error at /StackName/rFirstUser/DefaultPolicy/Resource] AwsSolutions-IAM5[Resource::*]: The IAM entity contains wildcard permissions and does not have a cdk_nag rule suppression with evidence for those permission.
+[Error at /StackName/rSecondUser/DefaultPolicy/Resource] AwsSolutions-IAM5[Action::s3:*]: The IAM entity contains wildcard permissions and does not have a cdk_nag rule suppression with evidence for those permission.
+[Error at /StackName/rSecondUser/DefaultPolicy/Resource] AwsSolutions-IAM5[Resource::*]: The IAM entity contains wildcard permissions and does not have a cdk_nag rule suppression with evidence for those permission.
+```
+
+By applying the following suppressions
+
+```python
+import { User } from '@aws-cdk/aws-iam';
+import { NagSuppressions } from 'cdk-nag';
+import { Construct, Stack, StackProps } from '@aws-cdk/core';
+
+export class CdkTestStack extends Stack {
+  constructor(scope: Construct, id: string, props?: StackProps) {
+    super(scope, id, props);
+    const firstUser = new User(this, 'rFirstUser');
+    firstUser.addToPolicy(
+      new PolicyStatement({
+        actions: ['s3:*'],
+        resources: ['*'],
+      })
+    );
+    const secondUser = new User(this, 'rSecondUser');
+    secondUser.addToPolicy(
+      new PolicyStatement({
+        actions: ['s3:*'],
+        resources: ['*'],
+      })
+    );
+    NagSuppressions.addResourceSuppressions(
+      firstUser,
+      [
+        {
+          id: 'AwsSolutions-IAM5',
+          reason:
+            "Only suppress AwsSolutions-IAM5 's3:*' finding on First User.",
+          appliesTo: ['Action::s3:*'],
+        },
+      ],
+      true
+    );
+    NagSuppressions.addResourceSuppressions(
+      secondUser,
+      [
+        {
+          id: 'AwsSolutions-IAM5',
+          reason: 'Suppress all AwsSolutions-IAM5 findings on Second User.',
+        },
+      ],
+      true
+    );
+  }
+}
+```
+
+You would see the following error on synth/deploy
+
+```bash
+[Error at /StackName/rFirstUser/DefaultPolicy/Resource] AwsSolutions-IAM5[Resource::*]: The IAM entity contains wildcard permissions and does not have a cdk_nag rule suppression with evidence for those permission.
+```
+
 </details>
 
 ## Rules and Property Overrides
@@ -232,7 +306,7 @@ export class CdkTestStack extends Stack {
 You can use cdk-nag on existing CloudFormation templates by using the [cloudformation-include](https://docs.aws.amazon.com/cdk/latest/guide/use_cfn_template.html#use_cfn_template_install) module.
 
 <details>
-  <summary>Example) CloudFormation template with suppression</summary>
+  <summary>Example 1) CloudFormation template with suppression</summary>
 
 Sample CloudFormation template with suppression
 
@@ -299,6 +373,94 @@ export class CdkTestStack extends Stack {
 }
 ```
 
+</details><details>
+  <summary>Example 2) CloudFormation template with granular suppressions</summary>
+
+Sample CloudFormation template with suppression
+
+```json
+{
+  "Resources": {
+    "myPolicy": {
+      "Type": "AWS::IAM::Policy",
+      "Properties": {
+        "PolicyDocument": {
+          "Statement": [
+            {
+              "Action": [
+                "kms:Decrypt",
+                "kms:DescribeKey",
+                "kms:Encrypt",
+                "kms:ReEncrypt*",
+                "kms:GenerateDataKey*"
+              ],
+              "Effect": "Allow",
+              "Resource": ["some-key-arn"]
+            }
+          ],
+          "Version": "2012-10-17"
+        }
+      },
+      "Metadata": {
+        "cdk_nag": {
+          "rules_to_suppress": [
+            {
+              "id": "AwsSolutions-IAM5",
+              "reason": "Allow key data access",
+              "applies_to": [
+                "Action::kms:ReEncrypt*",
+                "Action::kms:GenerateDataKey*"
+              ]
+            }
+          ]
+        }
+      }
+    }
+  }
+}
+```
+
+Sample App
+
+```python
+import { App, Aspects } from '@aws-cdk/core';
+import { CdkTestStack } from '../lib/cdk-test-stack';
+import { AwsSolutionsChecks } from 'cdk-nag';
+
+const app = new App();
+new CdkTestStack(app, 'CdkNagDemo');
+Aspects.of(app).add(new AwsSolutionsChecks());
+```
+
+Sample Stack with imported template
+
+```python
+import { CfnInclude } from '@aws-cdk/cloudformation-include';
+import { NagSuppressions } from 'cdk-nag';
+import { Construct, Stack, StackProps } from '@aws-cdk/core';
+
+export class CdkTestStack extends Stack {
+  constructor(scope: Construct, id: string, props?: StackProps) {
+    super(scope, id, props);
+    new CfnInclude(this, 'Template', {
+      templateFile: 'my-template.json',
+    });
+    // Add any additional suppressions
+    NagSuppressions.addResourceSuppressionsByPath(
+      this,
+      '/CdkNagDemo/Template/myPolicy',
+      [
+        {
+          id: 'AwsSolutions-IAM5',
+          reason: 'Allow key data access',
+          appliesTo: ['Action::kms:ReEncrypt*', 'Action::kms:GenerateDataKey*'],
+        },
+      ]
+    );
+  }
+}
+```
+
 </details>
 
 ## Contributing
@@ -379,7 +541,10 @@ class IApplyRule(typing_extensions.Protocol):
         ...
 
     @jsii.member(jsii_name="rule")
-    def rule(self, node: monocdk.CfnResource) -> "NagRuleCompliance":
+    def rule(
+        self,
+        node: monocdk.CfnResource,
+    ) -> typing.Union["NagRuleCompliance", typing.List[builtins.str]]:
         '''The callback to the rule.
 
         :param node: The CfnResource to check.
@@ -443,12 +608,15 @@ class _IApplyRuleProxy:
         jsii.set(self, "ruleSuffixOverride", value)
 
     @jsii.member(jsii_name="rule")
-    def rule(self, node: monocdk.CfnResource) -> "NagRuleCompliance":
+    def rule(
+        self,
+        node: monocdk.CfnResource,
+    ) -> typing.Union["NagRuleCompliance", typing.List[builtins.str]]:
         '''The callback to the rule.
 
         :param node: The CfnResource to check.
         '''
-        return typing.cast("NagRuleCompliance", jsii.invoke(self, "rule", [node]))
+        return typing.cast(typing.Union["NagRuleCompliance", typing.List[builtins.str]], jsii.invoke(self, "rule", [node]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
 typing.cast(typing.Any, IApplyRule).__jsii_proxy_class__ = lambda : _IApplyRuleProxy
@@ -515,33 +683,37 @@ class NagPack(metaclass=jsii.JSIIAbstractClass, jsii_type="monocdk-nag.NagPack")
     def _create_message(
         self,
         rule_id: builtins.str,
+        finding_id: builtins.str,
         info: builtins.str,
         explanation: builtins.str,
     ) -> builtins.str:
         '''The message to output to the console when a rule is triggered.
 
         :param rule_id: The id of the rule.
+        :param finding_id: The id of the finding.
         :param info: Why the rule was triggered.
         :param explanation: Why the rule exists.
 
         :return: The formatted message string.
         '''
-        return typing.cast(builtins.str, jsii.invoke(self, "createMessage", [rule_id, info, explanation]))
+        return typing.cast(builtins.str, jsii.invoke(self, "createMessage", [rule_id, finding_id, info, explanation]))
 
     @jsii.member(jsii_name="ignoreRule")
     def _ignore_rule(
         self,
         ignores: typing.Sequence["NagPackSuppression"],
         rule_id: builtins.str,
+        finding_id: builtins.str,
     ) -> builtins.str:
         '''Check whether a specific rule should be ignored.
 
         :param ignores: The ignores listed in cdk-nag metadata.
         :param rule_id: The id of the rule to ignore.
+        :param finding_id: The id of the finding that is being checked.
 
         :return: The reason the rule was ignored, or an empty string.
         '''
-        return typing.cast(builtins.str, jsii.invoke(self, "ignoreRule", [ignores, rule_id]))
+        return typing.cast(builtins.str, jsii.invoke(self, "ignoreRule", [ignores, rule_id, finding_id]))
 
     @jsii.member(jsii_name="visit") # type: ignore[misc]
     @abc.abstractmethod
@@ -704,19 +876,28 @@ class NagPackProps:
 @jsii.data_type(
     jsii_type="monocdk-nag.NagPackSuppression",
     jsii_struct_bases=[],
-    name_mapping={"id": "id", "reason": "reason"},
+    name_mapping={"id": "id", "reason": "reason", "applies_to": "appliesTo"},
 )
 class NagPackSuppression:
-    def __init__(self, *, id: builtins.str, reason: builtins.str) -> None:
+    def __init__(
+        self,
+        *,
+        id: builtins.str,
+        reason: builtins.str,
+        applies_to: typing.Optional[typing.Sequence[builtins.str]] = None,
+    ) -> None:
         '''Interface for creating a rule suppression.
 
         :param id: The id of the rule to ignore.
         :param reason: The reason to ignore the rule (minimum 10 characters).
+        :param applies_to: Rule specific granular suppressions.
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "id": id,
             "reason": reason,
         }
+        if applies_to is not None:
+            self._values["applies_to"] = applies_to
 
     @builtins.property
     def id(self) -> builtins.str:
@@ -732,6 +913,12 @@ class NagPackSuppression:
         assert result is not None, "Required property 'reason' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def applies_to(self) -> typing.Optional[typing.List[builtins.str]]:
+        '''Rule specific granular suppressions.'''
+        result = self._values.get("applies_to")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
